==> cockpit-podman-24-1-x86_64.pkg.tar.zst: usr/share/cockpit/podman/po.zh_CN.js <==
(function (root, data) {
    var loaded, module;

    /* Load into Cockpit locale */
    if (typeof cockpit === 'object') {
        cockpit.locale(data)
        loaded = true;
    }

    if (!loaded)
        root.po = data;

/* The syntax of this line is important  by po2json */
}(this, {
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=1; plural=0;
return plural;
},
  "language": "zh_CN",
  "x-generator": "Weblate 4.2.1"
 },
 "Add item": [
  null,
  "添加项目"
 ],
 "Add on build variable": [
  null,
  "添加构建变量"
 ],
 "All": [
  null,
  "所有"
 ],
 "All registries": [
  null,
  ""
 ],
 "An error occured": [
  null,
  "发生了一个错误"
 ],
 "Author": [
  null,
  "作者"
 ],
 "Automatically start podman on boot": [
  null,
  "开机自动启动 podman"
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "CPU shares": [
  null,
  "CPU 份额"
 ],
 "Cancel": [
  null,
  "取消"
 ],
 "Checkpoint": [
  null,
  "检查点"
 ],
 "Checkpoint container $0": [
  null,
  "提交容器 $0 失败"
 ],
 "Command": [
  null,
  "命令"
 ],
 "Commit": [
  null,
  "提交"
 ],
 "Commit image": [
  null,
  "提交镜像"
 ],
 "Console": [
  null,
  "控制台"
 ],
 "Container": [
  null,
  "容器"
 ],
 "Container failed to be created": [
  null,
  "容器创建失败"
 ],
 "Container failed to be started": [
  null,
  "容器启动失败"
 ],
 "Container is currently running.": [
  null,
  "容器正在运行。"
 ],
 "Container is not running": [
  null,
  "容器未运行"
 ],
 "Container name": [
  null,
  "容器名称"
 ],
 "Container path": [
  null,
  "容器路径"
 ],
 "Container port": [
  null,
  "容器端口"
 ],
 "Containers": [
  null,
  "容器"
 ],
 "Created": [
  null,
  "已创建"
 ],
 "Delete": [
  null,
  "删除"
 ],
 "Delete $0": [
  null,
  "删除 $0"
 ],
 "Delete image": [
  null,
  "删除镜像"
 ],
 "Delete tagged images": [
  null,
  "删除标记的镜像"
 ],
 "Deleting a container will erase all data in it.": [
  null,
  "删除容器会清空其中的全部数据。"
 ],
 "Deleting this pod will remove the following containers:": [
  null,
  "删除这个 Pod 将会移除这些容器："
 ],
 "Details": [
  null,
  "详情"
 ],
 "Do not include root file-system changes when exporting": [
  null,
  "导出时不包含 root 文件系统更改"
 ],
 "Download": [
  null,
  "下载"
 ],
 "Entrypoint": [
  null,
  "入口点"
 ],
 "Environment": [
  null,
  "环境"
 ],
 "Error": [
  null,
  "错误"
 ],
 "Error message": [
  null,
  "错误信息"
 ],
 "Exited": [
  null,
  "已退出"
 ],
 "Failed to checkpoint container $0": [
  null,
  "提交容器 $0 失败"
 ],
 "Failed to commit container $0": [
  null,
  "提交容器 $0 失败"
 ],
 "Failed to download image $0:$1": [
  null,
  "下载镜像 $0:$1 失败"
 ],
 "Failed to force remove container $0": [
  null,
  "强制移除容器 $0 失败"
 ],
 "Failed to force stop pod $0": [
  null,
  "强制停止 Pod $0 失败"
 ],
 "Failed to pause pod $0": [
  null,
  "暂停 Pod $0 失败"
 ],
 "Failed to remove container $0": [
  null,
  "移除容器 $0 失败"
 ],
 "Failed to restart container $0": [
  null,
  "重启容器 $0 失败"
 ],
 "Failed to restart pod $0": [
  null,
  "重启容器 $0 失败"
 ],
 "Failed to restore container $0": [
  null,
  "重启容器 $0 失败"
 ],
 "Failed to resume pod $0": [
  null,
  "恢复 Pod $0 失败"
 ],
 "Failed to search for images: $0": [
  null,
  "搜索镜像 $0 失败"
 ],
 "Failed to search for new images": [
  null,
  "搜索新镜像失败"
 ],
 "Failed to start container $0": [
  null,
  "启动容器 $0 失败"
 ],
 "Failed to start pod $0": [
  null,
  "启动 Pod $0 失败"
 ],
 "Failed to stop container $0": [
  null,
  "停止容器 $0 失败"
 ],
 "Failed to stop pod $0": [
  null,
  "停止 Pod $0 失败"
 ],
 "Force delete": [
  null,
  "强制删除"
 ],
 "Force restart": [
  null,
  "强制重启"
 ],
 "Force stop": [
  null,
  "强制停止"
 ],
 "Format": [
  null,
  "格式"
 ],
 "Gateway": [
  null,
  "网关"
 ],
 "Get new image": [
  null,
  "获取新镜像"
 ],
 "GiB": [
  null,
  "GiB"
 ],
 "Hide intermediate images": [
  null,
  "隐藏中间镜像"
 ],
 "Host path": [
  null,
  "主机路径"
 ],
 "Host port": [
  null,
  "主机端口"
 ],
 "ID": [
  null,
  "ID"
 ],
 "IP address": [
  null,
  "IP 地址"
 ],
 "IP prefix length": [
  null,
  "IP 前缀长度"
 ],
 "Ignore IP address if set statically": [
  null,
  ""
 ],
 "Ignore MAC address if set statically": [
  null,
  "忽略被静态设定的 MAC 地址"
 ],
 "Image": [
  null,
  "镜像"
 ],
 "Image name": [
  null,
  "镜像名称"
 ],
 "Images": [
  null,
  "镜像"
 ],
 "Keep all temporary checkpoint files": [
  null,
  "保留所有临时检查点文件"
 ],
 "Key": [
  null,
  "键"
 ],
 "KiB": [
  null,
  "KiB"
 ],
 "Leave running after writing checkpoint to disk": [
  null,
  ""
 ],
 "Loading logs...": [
  null,
  "加载中……"
 ],
 "Loading...": [
  null,
  "加载中……"
 ],
 "Logs": [
  null,
  "日志"
 ],
 "MAC address": [
  null,
  "MAC 地址"
 ],
 "Memory": [
  null,
  "内存"
 ],
 "Memory limit": [
  null,
  "内存限制"
 ],
 "Message": [
  null,
  "消息"
 ],
 "MiB": [
  null,
  "MiB"
 ],
 "Multiple tags exist for this image. Select the tagged images to delete.": [
  null,
  ""
 ],
 "Name": [
  null,
  "名称"
 ],
 "No SELinux label": [
  null,
  "无 SELinux 标签"
 ],
 "No containers": [
  null,
  "没有容器"
 ],
 "No containers are using this image": [
  null,
  "没有使用该镜像的容器"
 ],
 "No containers in this pod": [
  null,
  "没有使用该镜像的容器"
 ],
 "No containers that match the current filter": [
  null,
  "没有符合当前筛选条件的容器"
 ],
 "No images": [
  null,
  "没有镜像"
 ],
 "No images that match the current filter": [
  null,
  "没有符合当前筛选条件的镜像"
 ],
 "No results for $0. Please retry another term.": [
  null,
  "没有匹配 $0 的结果。请换个关键词重试。"
 ],
 "No running containers": [
  null,
  "没有正在运行的容器"
 ],
 "On build": [
  null,
  "构建时"
 ],
 "Only running": [
  null,
  "仅运行"
 ],
 "Owner": [
  null,
  "所有者"
 ],
 "Pause": [
  null,
  "暂停"
 ],
 "Pause the container": [
  null,
  "暂停该容器"
 ],
 "Paused": [
  null,
  "暂停"
 ],
 "Please confirm deletion of $0": [
  null,
  "请确认是否删除 $0"
 ],
 "Please confirm deletion of pod $0": [
  null,
  "请确认是否删除 $0"
 ],
 "Please confirm force deletion of pod $0": [
  null,
  "请确认是否强制删除 $0"
 ],
 "Please confirm forced deletion of $0": [
  null,
  "请确认是否强制删除 $0"
 ],
 "Podman containers": [
  null,
  "Podman 容器"
 ],
 "Podman service is not active": [
  null,
  "Podman 服务未激活"
 ],
 "Ports": [
  null,
  "端口"
 ],
 "Private": [
  null,
  "私有"
 ],
 "Pulling": [
  null,
  "正在拉取"
 ],
 "ReadOnly": [
  null,
  "只读"
 ],
 "ReadWrite": [
  null,
  "读写"
 ],
 "Remove item": [
  null,
  "删除项目"
 ],
 "Remove on build variable": [
  null,
  "设置容器构建时的变量"
 ],
 "Restart": [
  null,
  "重启"
 ],
 "Restore": [
  null,
  "重启"
 ],
 "Restore container $0": [
  null,
  "移除容器 $0 失败"
 ],
 "Restore with established TCP connections": [
  null,
  ""
 ],
 "Resume": [
  null,
  "继续"
 ],
 "Run": [
  null,
  "运行"
 ],
 "Run image": [
  null,
  "运行镜像"
 ],
 "Running": [
  null,
  "正在运行"
 ],
 "Search by name or description": [
  null,
  "按名称或描述搜索"
 ],
 "Search for": [
  null,
  "搜索镜像"
 ],
 "Search for an image": [
  null,
  "搜索镜像"
 ],
 "Set container on build variables": [
  null,
  "设置容器构建时的变量"
 ],
 "Shared": [
  null,
  "CPU 份额"
 ],
 "Show": [
  null,
  "显示"
 ],
 "Show intermediate images": [
  null,
  "显示中间镜像"
 ],
 "Size": [
  null,
  "大小"
 ],
 "Start": [
  null,
  "启动"
 ],
 "Start podman": [
  null,
  "启动 podman"
 ],
 "State": [
  null,
  "状态"
 ],
 "Stop": [
  null,
  "停止"
 ],
 "Stopped": [
  null,
  "停止"
 ],
 "Support preserving established TCP connections": [
  null,
  ""
 ],
 "System": [
  null,
  "系统"
 ],
 "System Podman service is also available": [
  null,
  "系统 Podman 服务同样可用"
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Tag": [
  null,
  "标签"
 ],
 "Tags": [
  null,
  "标签"
 ],
 "Troubleshoot": [
  null,
  "故障排除"
 ],
 "Type to filter…": [
  null,
  "输入筛选条件……"
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Up since $0": [
  null,
  "自 $0 开始运行"
 ],
 "Used by": [
  null,
  "使用者"
 ],
 "User": [
  null,
  "用户"
 ],
 "User Podman service is also available": [
  null,
  "用户 Podman 服务同样可用"
 ],
 "Value": [
  null,
  "值"
 ],
 "Volumes": [
  null,
  "卷"
 ],
 "With terminal": [
  null,
  "分配伪终端"
 ],
 "configured": [
  null,
  "已配置"
 ],
 "container": [
  null,
  "容器"
 ],
 "created": [
  null,
  "已创建"
 ],
 "exited": [
  null,
  "已退出"
 ],
 "image": [
  null,
  "镜像"
 ],
 "in": [
  null,
  ""
 ],
 "n/a": [
  null,
  "不适用"
 ],
 "not available": [
  null,
  "不可用"
 ],
 "paused": [
  null,
  "暂停"
 ],
 "pod group": [
  null,
  "Pod 组"
 ],
 "podman": [
  null,
  "启动 podman"
 ],
 "removing": [
  null,
  "正在删除"
 ],
 "running": [
  null,
  "正在运行"
 ],
 "select all": [
  null,
  "全选"
 ],
 "stopped": [
  null,
  "已停止"
 ],
 "system": [
  null,
  "系统"
 ],
 "user": [
  null,
  "用户"
 ]
}));

==> cockpit-podman-30-1-x86_64.pkg.tar.zst: usr/share/cockpit/podman/po.zh_CN.js <==
cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=1; plural=0;
return plural;
},
  "language": "zh_CN",
  "x-generator": "Weblate 4.4.2"
 },
 "Add item": [
  null,
  "添加项目"
 ],
 "Add on build variable": [
  null,
  "添加构建变量"
 ],
 "All": [
  null,
  "所有"
 ],
 "All registries": [
  null,
  ""
 ],
 "An error occured": [
  null,
  "发生了一个错误"
 ],
 "Author": [
  null,
  "作者"
 ],
 "Automatically start podman on boot": [
  null,
  "开机自动启动 podman"
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "CPU shares": [
  null,
  "CPU 份额"
 ],
 "Cancel": [
  null,
  "取消"
 ],
 "Checkpoint": [
  null,
  "检查点"
 ],
 "Command": [
  null,
  "命令"
 ],
 "Commit": [
  null,
  "提交"
 ],
 "Commit image": [
  null,
  "提交镜像"
 ],
 "Console": [
  null,
  "控制台"
 ],
 "Container failed to be created": [
  null,
  "容器创建失败"
 ],
 "Container failed to be started": [
  null,
  "容器启动失败"
 ],
 "Container is currently running.": [
  null,
  "容器正在运行。"
 ],
 "Container is not running": [
  null,
  "容器未运行"
 ],
 "Container name": [
  null,
  "容器名称"
 ],
 "Container path": [
  null,
  "容器路径"
 ],
 "Container port": [
  null,
  "容器端口"
 ],
 "Containers": [
  null,
  "容器"
 ],
 "Created": [
  null,
  "已创建"
 ],
 "Delete": [
  null,
  "删除"
 ],
 "Delete $0": [
  null,
  "删除 $0"
 ],
 "Delete image": [
  null,
  "删除镜像"
 ],
 "Delete tagged images": [
  null,
  "删除标记的镜像"
 ],
 "Deleting a container will erase all data in it.": [
  null,
  "删除容器会清空其中的全部数据。"
 ],
 "Deleting this pod will remove the following containers:": [
  null,
  "删除这个 Pod 将会移除这些容器："
 ],
 "Details": [
  null,
  "详情"
 ],
 "Do not include root file-system changes when exporting": [
  null,
  "导出时不包含 root 文件系统更改"
 ],
 "Download": [
  null,
  "下载"
 ],
 "Entrypoint": [
  null,
  "入口点"
 ],
 "Environment": [
  null,
  "环境"
 ],
 "Error": [
  null,
  "错误"
 ],
 "Error message": [
  null,
  "错误信息"
 ],
 "Error occured while connecting console": [
  null,
  "连接到控制台时出现错误"
 ],
 "Exited": [
  null,
  "已退出"
 ],
 "Failed to commit container $0": [
  null,
  "提交容器 $0 失败"
 ],
 "Failed to download image $0:$1": [
  null,
  "下载镜像 $0:$1 失败"
 ],
 "Failed to force remove container $0": [
  null,
  "强制移除容器 $0 失败"
 ],
 "Failed to force stop pod $0": [
  null,
  "强制停止 Pod $0 失败"
 ],
 "Failed to pause pod $0": [
  null,
  "暂停 Pod $0 失败"
 ],
 "Failed to remove container $0": [
  null,
  "移除容器 $0 失败"
 ],
 "Failed to restart container $0": [
  null,
  "重启容器 $0 失败"
 ],
 "Failed to resume pod $0": [
  null,
  "恢复 Pod $0 失败"
 ],
 "Failed to search for images: $0": [
  null,
  "搜索镜像 $0 失败"
 ],
 "Failed to search for new images": [
  null,
  "搜索新镜像失败"
 ],
 "Failed to start container $0": [
  null,
  "启动容器 $0 失败"
 ],
 "Failed to start pod $0": [
  null,
  "启动 Pod $0 失败"
 ],
 "Failed to stop container $0": [
  null,
  "停止容器 $0 失败"
 ],
 "Failed to stop pod $0": [
  null,
  "停止 Pod $0 失败"
 ],
 "Force delete": [
  null,
  "强制删除"
 ],
 "Force restart": [
  null,
  "强制重启"
 ],
 "Force stop": [
  null,
  "强制停止"
 ],
 "Format": [
  null,
  "格式"
 ],
 "Gateway": [
  null,
  "网关"
 ],
 "Get new image": [
  null,
  "获取新镜像"
 ],
 "GiB": [
  null,
  "GiB"
 ],
 "Hide intermediate images": [
  null,
  "隐藏中间镜像"
 ],
 "Host path": [
  null,
  "主机路径"
 ],
 "ID": [
  null,
  "ID"
 ],
 "IP (optional)": [
  null,
  ""
 ],
 "IP address": [
  null,
  "IP 地址"
 ],
 "IP prefix length": [
  null,
  "IP 前缀长度"
 ],
 "Ignore IP address if set statically": [
  null,
  ""
 ],
 "Ignore MAC address if set statically": [
  null,
  "忽略被静态设定的 MAC 地址"
 ],
 "Image": [
  null,
  "镜像"
 ],
 "Image name": [
  null,
  "镜像名称"
 ],
 "Images": [
  null,
  "镜像"
 ],
 "Keep all temporary checkpoint files": [
  null,
  "保留所有临时检查点文件"
 ],
 "Key": [
  null,
  "键"
 ],
 "KiB": [
  null,
  "KiB"
 ],
 "Leave running after writing checkpoint to disk": [
  null,
  ""
 ],
 "Loading...": [
  null,
  "加载中……"
 ],
 "Logs": [
  null,
  "日志"
 ],
 "MAC address": [
  null,
  "MAC 地址"
 ],
 "Memory": [
  null,
  "内存"
 ],
 "Memory limit": [
  null,
  "内存限制"
 ],
 "Message": [
  null,
  "消息"
 ],
 "MiB": [
  null,
  "MiB"
 ],
 "Mode": [
  null,
  ""
 ],
 "Multiple tags exist for this image. Select the tagged images to delete.": [
  null,
  ""
 ],
 "Name": [
  null,
  "名称"
 ],
 "No SELinux label": [
  null,
  "无 SELinux 标签"
 ],
 "No containers": [
  null,
  "没有容器"
 ],
 "No containers are using this image": [
  null,
  "没有使用该镜像的容器"
 ],
 "No containers that match the current filter": [
  null,
  "没有符合当前筛选条件的容器"
 ],
 "No images": [
  null,
  "没有镜像"
 ],
 "No images that match the current filter": [
  null,
  "没有符合当前筛选条件的镜像"
 ],
 "No results for $0": [
  null,
  ""
 ],
 "No running containers": [
  null,
  "没有正在运行的容器"
 ],
 "Only running": [
  null,
  "仅运行"
 ],
 "Owner": [
  null,
  "所有者"
 ],
 "Pause": [
  null,
  "暂停"
 ],
 "Pause the container": [
  null,
  "暂停该容器"
 ],
 "Please confirm deletion of $0": [
  null,
  "请确认是否删除 $0"
 ],
 "Please confirm forced deletion of $0": [
  null,
  "请确认是否强制删除 $0"
 ],
 "Please start typing to look for images.": [
  null,
  ""
 ],
 "Podman containers": [
  null,
  "Podman 容器"
 ],
 "Podman service is not active": [
  null,
  "Podman 服务未激活"
 ],
 "Ports": [
  null,
  "端口"
 ],
 "Private": [
  null,
  "私有"
 ],
 "Protocol": [
  null,
  ""
 ],
 "Pulling": [
  null,
  "正在拉取"
 ],
 "ReadOnly": [
  null,
  "只读"
 ],
 "ReadWrite": [
  null,
  "读写"
 ],
 "Remove item": [
  null,
  "删除项目"
 ],
 "Restart": [
  null,
  "重启"
 ],
 "Restore with established TCP connections": [
  null,
  ""
 ],
 "Resume": [
  null,
  "继续"
 ],
 "Run": [
  null,
  "运行"
 ],
 "Run image": [
  null,
  "运行镜像"
 ],
 "Running": [
  null,
  "正在运行"
 ],
 "Search by name or description": [
  null,
  "按名称或描述搜索"
 ],
 "Set container on build variables": [
  null,
  "设置容器构建时的变量"
 ],
 "Show": [
  null,
  "显示"
 ],
 "Show intermediate images": [
  null,
  "显示中间镜像"
 ],
 "Size": [
  null,
  "大小"
 ],
 "Start": [
  null,
  "启动"
 ],
 "Start podman": [
  null,
  "启动 podman"
 ],
 "State": [
  null,
  "状态"
 ],
 "Stop": [
  null,
  "停止"
 ],
 "Support preserving established TCP connections": [
  null,
  ""
 ],
 "System": [
  null,
  "系统"
 ],
 "System Podman service is also available": [
  null,
  "系统 Podman 服务同样可用"
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Tag": [
  null,
  "标签"
 ],
 "Tags": [
  null,
  "标签"
 ],
 "Troubleshoot": [
  null,
  "故障排除"
 ],
 "Type to filter…": [
  null,
  "输入筛选条件……"
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Up since $0": [
  null,
  "自 $0 开始运行"
 ],
 "Used by": [
  null,
  "使用者"
 ],
 "User": [
  null,
  "用户"
 ],
 "User Podman service is also available": [
  null,
  "用户 Podman 服务同样可用"
 ],
 "Value": [
  null,
  "值"
 ],
 "Volumes": [
  null,
  "卷"
 ],
 "With terminal": [
  null,
  "分配伪终端"
 ],
 "configured": [
  null,
  "已配置"
 ],
 "in": [
  null,
  ""
 ],
 "n/a": [
  null,
  "不适用"
 ],
 "not available": [
  null,
  "不可用"
 ],
 "pod group": [
  null,
  "Pod 组"
 ],
 "removing": [
  null,
  "正在删除"
 ],
 "running": [
  null,
  "正在运行"
 ],
 "select all": [
  null,
  "全选"
 ],
 "stopped": [
  null,
  "已停止"
 ],
 "system": [
  null,
  "系统"
 ]
});
